# Example apps

The following examples show `okcourse` integrations in different application types.

| Application type              | Course generator                                        |
| ----------------------------- | ------------------------------------------------------- |
| [CLI](cli-async.md)           | [`OpenAIAsyncGenerator`][okcourse.OpenAIAsyncGenerator] |
| [Streamlit](streamlit-app.md) | [`OpenAIAsyncGenerator`][okcourse.OpenAIAsyncGenerator] |
